@@ -1,8 +1,6 @@
 from .details import details
 from .permissions import permissions
-from .reviews import (
-    reviews_first_page, reviews_next_page
-)
+from .reviews import reviews_next_page
 from .review_history import review_history
 from .search import (
     search_first_page, search_next_page
