@@ -31,7 +31,7 @@ def review_history(app_id, review_id):
 
     Raises
     ------
-    InputTypeError | InputValueError        
+    TypeError | ValueError        
     """
     validators.review_history(app_id, review_id)
     try:
@@ -39,7 +39,7 @@ def review_history(app_id, review_id):
         response = _do_get_review_history(form)
         return parsers.review_history(response.text)
     except:
-        logging.error('Unexpected error.')
+        logging.exception('Unexpected error.')
         return None
 
 
